@@ -7,11 +7,7 @@ function (x, xmin=NULL) {
 		x <- x - min(x, na.rm=TRUE) + xmin
 	} else {					# xmin is not given, we construct julian dates (compatibles with chron, dates,...)
 		if(is.null(yearorig <- options("chron.origin")$year))
-			if (exists("is.R") && is.function(is.R) && is.R()) {	# We are in R
-				yearorig <- 1970
-			} else {												# We are in Splus
-				yearorig <- 1960
-			}
+			yearorig <- 1970
 		x <- (x - yearorig) * 365.25
 	}
 	x
